@@ -15,7 +15,7 @@
  *       disclaimer in the documentation and/or other materials provided
  *       with the distribution.
  * 
- *     * Neither the name of the Technische Universität Berlin nor the
+ *     * Neither the name of the Technische Universitaet Berlin nor the
  *       names of its contributors may be used to endorse or promote
  *       products derived from this software without specific prior
  *       written permission.
@@ -60,7 +60,7 @@ public class ComplexDoubleMatrix {
 
 	/**
    * Create a new matrix with <i>newRows</i> rows, <i>newColumns</i> columns
-	 * using <i>newData></i> as the data.
+	 * using <i>newData</i> as the data.
 	 */
 	public ComplexDoubleMatrix(int newRows, int newColumns, double... newData) {
 		rows = newRows;
@@ -120,7 +120,9 @@ public class ComplexDoubleMatrix {
    * part can be set to null in which case it will be ignored.
    */
   public ComplexDoubleMatrix(DoubleMatrix real, DoubleMatrix imag) {
-      this(real.rows, real.columns);
+      this((real != null) ? real.rows : imag.rows, (real != null) ? real.columns : imag.columns);
+
+      if (real != null && imag != null)
       real.assertSameSize(imag);
 
       if (real != null)
@@ -142,8 +144,8 @@ public class ComplexDoubleMatrix {
 	 * Creates a new <i>n</i> times <i>m</i> <tt>ComplexDoubleMatrix</tt> from
 	 * the given <i>n</i> times <i>m</i> 2D data array. The first dimension of the array makes the
 	 * rows (<i>n</i>) and the second dimension the columns (<i>m</i>). For example, the
-	 * given code <br/><br/>
-	 * <code>new ComplexDoubleMatrix(new double[][]{{1d, 2d, 3d}, {4d, 5d, 6d}, {7d, 8d, 9d}}).print();</code><br/><br/>
+	 * given code <br><br>
+	 * <code>new ComplexDoubleMatrix(new double[][]{{1d, 2d, 3d}, {4d, 5d, 6d}, {7d, 8d, 9d}}).print();</code><br><br>
 	 * will constructs the following matrix:
 	 * <pre>
 	 * 1.0	2.0	3.0
@@ -1470,8 +1472,14 @@ public class ComplexDoubleMatrix {
 	 * @throws IOException thrown on errors while writing the matrix to the file
 	 */
 	public void save(String filename) throws IOException {
-		DataOutputStream dos = new DataOutputStream(new FileOutputStream(filename, false));
-		this.out(dos);
+            FileOutputStream fos = new FileOutputStream(filename, false);
+            DataOutputStream dos = new DataOutputStream(fos);
+            try {
+                 this.out(dos);
+            } finally {
+                dos.close();
+                fos.close();
+            }
 	}
 	
 	/**
@@ -1481,8 +1489,14 @@ public class ComplexDoubleMatrix {
 	 * @throws IOException thrown on errors while reading the matrix
 	 */
 	public void load(String filename) throws IOException {
-		DataInputStream dis = new DataInputStream(new FileInputStream(filename));
+            FileInputStream fis = new FileInputStream(filename);
+            DataInputStream dis = new DataInputStream(fis);
+            try {
 		this.in(dis);
+            } finally {
+                dis.close();
+                fis.close();
+            }
 	}
 
 	/****************************************************************
