@@ -15,7 +15,7 @@
  *       disclaimer in the documentation and/or other materials provided
  *       with the distribution.
  * 
- *     * Neither the name of the Technische Universität Berlin nor the
+ *     * Neither the name of the Technische Universitaet Berlin nor the
  *       names of its contributors may be used to endorse or promote
  *       products derived from this software without specific prior
  *       written permission.
@@ -666,6 +666,30 @@ public class TestDoubleMatrix extends AbstractTestJblas {
     assertEquals(2, i[3]);
   }
 
+  @Test
+  public void testColumnAndRowMinMaxUnsorted() {
+    assertEquals(new DoubleMatrix(1, 3, -2.0, -6.0, -8.0), E.columnMins());
+    assertEquals(new DoubleMatrix(3, 1, -4.0, -8.0, -6.0), E.rowMins());
+    assertEquals(new DoubleMatrix(1, 3, 3.0, 5.0, 9.0), E.columnMaxs());
+    assertEquals(new DoubleMatrix(3, 1, 7.0, 5.0, 9.0), E.rowMaxs());
+    int[] i = E.columnArgmins();
+    assertEquals(1, i[0]);
+    assertEquals(2, i[1]);
+    assertEquals(1, i[2]);
+    i = E.columnArgmaxs();
+    assertEquals(2, i[0]);
+    assertEquals(1, i[1]);
+    assertEquals(2, i[2]);
+    i = E.rowArgmins();
+    assertEquals(1, i[0]);
+    assertEquals(2, i[1]);
+    assertEquals(1, i[2]);
+    i = E.rowArgmaxs();
+    assertEquals(2, i[0]);
+    assertEquals(1, i[1]);
+    assertEquals(2, i[2]);
+  }
+
   @Test
   public void testToArray() {
     assertTrue(Arrays.equals(new double[]{2.0, 4.0, 8.0}, B.toArray()));
